@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -392,7 +392,7 @@ void codegen_gen_expr(
         } else if( ESUPPL_STATIC_BASE( expr->suppl ) == QSTRING ) {
 
           unsigned int slen;
-          tmpstr = vector_to_string( expr->value, QSTRING, FALSE );
+          tmpstr = vector_to_string( expr->value, QSTRING, FALSE, 0 );
           slen   = strlen( tmpstr ) + 3;
           (*code)[0] = (char*)malloc_safe( slen );
           rv = snprintf( (*code)[0], slen, "\"%s\"", tmpstr );
@@ -401,7 +401,7 @@ void codegen_gen_expr(
 
         } else { 
 
-          (*code)[0] = vector_to_string( expr->value, ESUPPL_STATIC_BASE( expr->suppl ), FALSE );
+          (*code)[0] = vector_to_string( expr->value, ESUPPL_STATIC_BASE( expr->suppl ), FALSE, 0 );
 
         }
    
@@ -986,6 +986,10 @@ void codegen_gen_expr(
           codegen_create_expr( code, code_depth, expr->line, "$unsigned( ", left_code, left_code_depth, expr->left, " )",
                                NULL, 0, NULL, NULL );
           break;
+        case EXP_OP_SCLOG2 :
+          codegen_create_expr( code, code_depth, expr->line, "$clog2( ", left_code, left_code_depth, expr->left, " )",
+                               NULL, 0, NULL, NULL );
+          break;
         case EXP_OP_SRANDOM  :
           codegen_create_expr( code, code_depth, expr->line, "$random( ", left_code, left_code_depth, expr->left, " )",
                                NULL, 0, NULL, NULL );
