@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -440,7 +440,7 @@ void gitem_link_display(
 
   curr = head;
   while( curr != NULL ) {
-    gen_item_display_block( curr->gi );
+    (void)gen_item_display_block( curr->gi );
     curr = curr->next;
   }
 
