@@ -2,7 +2,7 @@
 #define __TCL_FUNCS_H__
 
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -41,7 +41,8 @@ void tcl_func_initialize(
   const char* user_home,
   const char* home,
   const char* version,
-  const char* browser
+  const char* browser,
+  const char* input_cdd
 );
 
 #endif
