@@ -2,7 +2,7 @@
 #define __UTIL_H__
 
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -52,8 +52,11 @@
 #endif
 
 
-/*! \brief Sets error suppression to specified value */
-void set_output_suppression( bool value );
+/*! \brief Sets quiet output variable to specified value */
+void set_quiet( bool value );
+
+/*! \brief Sets terse output variable to specified value */
+void set_terse( bool value );
 
 /*! \brief Sets global debug flag to specified value */
 void set_debug( bool value );
