@@ -2,7 +2,7 @@
 #define __VECTOR_H__
 
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -329,9 +329,10 @@ bool vector_from_real64(
 
 /*! \brief Converts vector into a string value in specified format. */
 char* vector_to_string(
-  vector* vec, 
-  int     base,
-  bool    show_all
+  vector*      vec, 
+  int          base,
+  bool         show_all,
+  unsigned int width
 );
 
 /*! \brief Converts a string to a preallocated vector. */
@@ -656,6 +657,12 @@ bool vector_op_list(
   const vector* right
 );
 
+/*! \brief Performs clog2 operation. */
+bool vector_op_clog2(
+  vector*       tgt,
+  const vector* src
+);
+
 /*! \brief Deallocates the value structure for the given vector. */
 void vector_dealloc_value(
   vector* vec
