@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2006-2009 Trevor Williams
+ Copyright (c) 2006-2010 Trevor Williams
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by the Free Software
@@ -26,6 +26,9 @@
 #ifdef CVER
 #include "cv_vpi_user.h"
 #endif
+#ifdef NCV
+#include "vpi_user_cds.h"
+#endif
 
 #include "binding.h"
 #include "db.h"
@@ -61,7 +64,6 @@ sym_value* sv_head       = NULL;   /*!< Pointer to head of sym_value list */
 sym_value* sv_tail       = NULL;   /*!< Pointer to tail of sym_value list */
 
 /* These are needed for compile purposes only */
-bool   report_gui          = FALSE;
 int    timestep_update     = 0;
 bool   report_covered      = FALSE;
 bool   flag_use_line_width = FALSE;
@@ -851,19 +853,27 @@ PLI_INT32 covered_sim_calltf( char* name ) {
 }
 
 void covered_register() {
-
   s_vpi_systf_data tf_data;
 
+  vpi_printf("VPI: Registering covered_sim system_task");
+
   tf_data.type      = vpiSysTask;
   tf_data.tfname    = "$covered_sim";
   tf_data.calltf    = covered_sim_calltf;
   tf_data.compiletf = 0;
   tf_data.sizetf    = 0;
   tf_data.user_data = "$covered_sim";
+
   vpi_register_systf( &tf_data );
+  if (vpi_chk_error(NULL)) {
+    vpi_printf("Error occured while setting up user %s\n",
+               "defined system tasks and functions.");
+    return;
+  }
 
 }
 
+
 #ifndef VCS
 void (*vlog_startup_routines[])() = {
 	covered_register,
